searchData={"items":[{"type":"module","title":"ExMCP","doc":"ExMCP - Elixir implementation of the Model Context Protocol.\n\nThis is the main entry point for the ExMCP library. For most use cases,\nyou'll want to use the specific modules:\n\n- `ExMCP.Client` - For connecting to MCP servers\n- `ExMCP.Server` - For implementing MCP servers\n- `ExMCP.ServerManager` - For managing multiple server connections\n- `ExMCP.Discovery` - For discovering available MCP servers","ref":"ExMCP.html"},{"type":"module","title":"Quick Examples - ExMCP","doc":"","ref":"ExMCP.html#module-quick-examples"},{"type":"module","title":"Client Usage - ExMCP","doc":"# Connect to a filesystem MCP server\n    {:ok, client} = ExMCP.Client.start_link(\n      transport: :stdio,\n      command: [\"npx\", \"-y\", \"@modelcontextprotocol/server-filesystem\", \"/tmp\"]\n    )\n\n    # List and call tools\n    {:ok, tools} = ExMCP.Client.list_tools(client)\n    {:ok, result} = ExMCP.Client.call_tool(client, \"read_file\", %{\"path\" => \"/tmp/test.txt\"})","ref":"ExMCP.html#module-client-usage"},{"type":"module","title":"Server Usage - ExMCP","doc":"defmodule MyServer do\n      use ExMCP.Server.Handler\n\n      @impl true\n      def handle_list_tools(state) do\n        tools = [%{name: \"hello\", description: \"Say hello\"}]\n        {:ok, tools, state}\n      end\n\n      @impl true\n      def handle_call_tool(\"hello\", %{\"name\" => name} = _args, state) do\n        {:ok, [%{type: \"text\", text: \"Hello, \" <> name <> \"!\"}], state}\n      end\n    end\n\n    {:ok, server} = ExMCP.Server.start_link(\n      handler: MyServer,\n      transport: :stdio\n    )","ref":"ExMCP.html#module-server-usage"},{"type":"function","title":"ExMCP.protocol_version/0","doc":"Returns the version of the MCP protocol this library implements.","ref":"ExMCP.html#protocol_version/0"},{"type":"function","title":"ExMCP.version/0","doc":"Returns the version of the ExMCP library.","ref":"ExMCP.html#version/0"},{"type":"module","title":"ExMCP.Transport.Beam","doc":"BEAM message passing transport for MCP.\n\nThis transport uses native Erlang message passing for communication\nbetween MCP clients and servers running on the same BEAM VM or\ndistributed across Erlang nodes.\n\nBenefits:\n- Zero serialization overhead for local connections\n- Built-in supervision and fault tolerance\n- Native distributed support (connect to remote BEAM nodes)\n- Better performance for Elixir-based MCP tools\n- Maintains supervision tree integrity\n\nSupports both:\n- Local connections (same VM): Uses direct process references\n- Distributed connections (remote nodes): Uses {name, node} tuples","ref":"ExMCP.Transport.Beam.html"},{"type":"function","title":"ExMCP.Transport.Beam.discover_cluster_servers/0","doc":"Discovers BEAM transport servers across the cluster.","ref":"ExMCP.Transport.Beam.html#discover_cluster_servers/0"},{"type":"function","title":"ExMCP.Transport.Beam.discover_local_servers/0","doc":"Discovers BEAM transport servers on the current node.","ref":"ExMCP.Transport.Beam.html#discover_local_servers/0"},{"type":"type","title":"ExMCP.Transport.Beam.distributed_config/0","doc":"","ref":"ExMCP.Transport.Beam.html#t:distributed_config/0"},{"type":"type","title":"ExMCP.Transport.Beam.local_config/0","doc":"","ref":"ExMCP.Transport.Beam.html#t:local_config/0"},{"type":"function","title":"ExMCP.Transport.Beam.register_server/2","doc":"Registers a server on the current node for discovery.\n\nThis allows the server to be found by clients using\nExMCP.Discovery functions.","ref":"ExMCP.Transport.Beam.html#register_server/2"},{"type":"type","title":"ExMCP.Transport.Beam.server_config/0","doc":"","ref":"ExMCP.Transport.Beam.html#t:server_config/0"},{"type":"function","title":"ExMCP.Transport.Beam.start_server/3","doc":"Starts a BEAM transport server that can accept connections.\n\nThis creates a named process that MCP clients can connect to\nusing the BEAM transport.","ref":"ExMCP.Transport.Beam.html#start_server/3"},{"type":"type","title":"ExMCP.Transport.Beam.t/0","doc":"","ref":"ExMCP.Transport.Beam.html#t:t/0"},{"type":"module","title":"ExMCP.Transport.Beam.Server","doc":"GenServer implementation for BEAM transport MCP servers.\n\nThis server handles incoming BEAM transport connections and\nroutes MCP messages to the appropriate handler.","ref":"ExMCP.Transport.Beam.Server.html"},{"type":"function","title":"ExMCP.Transport.Beam.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExMCP.Transport.Beam.Server.html#child_spec/1"},{"type":"function","title":"ExMCP.Transport.Beam.Server.start_link/1","doc":"","ref":"ExMCP.Transport.Beam.Server.html#start_link/1"},{"type":"module","title":"ExMCP.Transport.SSE","doc":"Server-Sent Events (SSE) transport for MCP.\n\nThis transport uses HTTP SSE for server-to-client messages\nand HTTP POST for client-to-server messages.","ref":"ExMCP.Transport.SSE.html"},{"type":"type","title":"ExMCP.Transport.SSE.t/0","doc":"","ref":"ExMCP.Transport.SSE.html#t:t/0"},{"type":"module","title":"ExMCP.Transport.Stdio","doc":"stdio transport implementation for MCP.\n\nThis transport communicates with MCP servers over standard input/output,\ntypically by spawning a subprocess.","ref":"ExMCP.Transport.Stdio.html"},{"type":"module","title":"Options - ExMCP.Transport.Stdio","doc":"- `:command` - Command and arguments to spawn (required)\n- `:cd` - Working directory for the process\n- `:env` - Environment variables as a list of {\"KEY\", \"VALUE\"} tuples","ref":"ExMCP.Transport.Stdio.html#module-options"},{"type":"module","title":"Example - ExMCP.Transport.Stdio","doc":"{:ok, client} = ExMCP.Client.start_link(\n      transport: :stdio,\n      command: [\"node\", \"my-mcp-server.js\"],\n      cd: \"/path/to/server\",\n      env: [{\"NODE_ENV\", \"production\"}]\n    )","ref":"ExMCP.Transport.Stdio.html#module-example"},{"type":"module","title":"ExMCP.Protocol","doc":"MCP protocol message encoding and decoding.\n\nImplements the Model Context Protocol JSON-RPC message format.\nThis module handles the low-level protocol details for both\nclient and server implementations.","ref":"ExMCP.Protocol.html"},{"type":"function","title":"ExMCP.Protocol.encode_call_tool/2","doc":"Encodes a tool call request.","ref":"ExMCP.Protocol.html#encode_call_tool/2"},{"type":"function","title":"ExMCP.Protocol.encode_complete/2","doc":"Encodes a completion request.","ref":"ExMCP.Protocol.html#encode_complete/2"},{"type":"function","title":"ExMCP.Protocol.encode_error/4","doc":"Encodes an error response.","ref":"ExMCP.Protocol.html#encode_error/4"},{"type":"function","title":"ExMCP.Protocol.encode_get_prompt/2","doc":"Encodes a prompt get request.","ref":"ExMCP.Protocol.html#encode_get_prompt/2"},{"type":"function","title":"ExMCP.Protocol.encode_initialize/1","doc":"Encodes an initialize request from client to server.","ref":"ExMCP.Protocol.html#encode_initialize/1"},{"type":"function","title":"ExMCP.Protocol.encode_initialized/0","doc":"Encodes an initialized notification.","ref":"ExMCP.Protocol.html#encode_initialized/0"},{"type":"function","title":"ExMCP.Protocol.encode_list_prompts/0","doc":"Encodes a request to list available prompts.","ref":"ExMCP.Protocol.html#encode_list_prompts/0"},{"type":"function","title":"ExMCP.Protocol.encode_list_resources/0","doc":"Encodes a request to list available resources.","ref":"ExMCP.Protocol.html#encode_list_resources/0"},{"type":"function","title":"ExMCP.Protocol.encode_list_tools/0","doc":"Encodes a request to list available tools.","ref":"ExMCP.Protocol.html#encode_list_tools/0"},{"type":"function","title":"ExMCP.Protocol.encode_notification/2","doc":"Encodes a notification (no id field).","ref":"ExMCP.Protocol.html#encode_notification/2"},{"type":"function","title":"ExMCP.Protocol.encode_read_resource/1","doc":"Encodes a resource read request.","ref":"ExMCP.Protocol.html#encode_read_resource/1"},{"type":"function","title":"ExMCP.Protocol.encode_response/2","doc":"Encodes a successful response.","ref":"ExMCP.Protocol.html#encode_response/2"},{"type":"function","title":"ExMCP.Protocol.encode_to_string/1","doc":"Encodes a message to JSON string.","ref":"ExMCP.Protocol.html#encode_to_string/1"},{"type":"type","title":"ExMCP.Protocol.error/0","doc":"","ref":"ExMCP.Protocol.html#t:error/0"},{"type":"function","title":"ExMCP.Protocol.generate_id/0","doc":"Generates a unique ID for requests.","ref":"ExMCP.Protocol.html#generate_id/0"},{"type":"function","title":"ExMCP.Protocol.internal_error/0","doc":"","ref":"ExMCP.Protocol.html#internal_error/0"},{"type":"function","title":"ExMCP.Protocol.invalid_params/0","doc":"","ref":"ExMCP.Protocol.html#invalid_params/0"},{"type":"function","title":"ExMCP.Protocol.invalid_request/0","doc":"","ref":"ExMCP.Protocol.html#invalid_request/0"},{"type":"type","title":"ExMCP.Protocol.json_rpc_id/0","doc":"","ref":"ExMCP.Protocol.html#t:json_rpc_id/0"},{"type":"type","title":"ExMCP.Protocol.method/0","doc":"","ref":"ExMCP.Protocol.html#t:method/0"},{"type":"function","title":"ExMCP.Protocol.method_not_found/0","doc":"","ref":"ExMCP.Protocol.html#method_not_found/0"},{"type":"type","title":"ExMCP.Protocol.params/0","doc":"","ref":"ExMCP.Protocol.html#t:params/0"},{"type":"function","title":"ExMCP.Protocol.parse_error/0","doc":"Standard JSON-RPC error codes.","ref":"ExMCP.Protocol.html#parse_error/0"},{"type":"function","title":"ExMCP.Protocol.parse_message/1","doc":"Parses a JSON-RPC message.\n\nReturns one of:\n- `{:request, method, params, id}` - An incoming request\n- `{:notification, method, params}` - An incoming notification\n- `{:result, result, id}` - A response to our request\n- `{:error, error, id}` - An error response\n- `{:error, :invalid_message}` - Invalid message format","ref":"ExMCP.Protocol.html#parse_message/1"},{"type":"type","title":"ExMCP.Protocol.result/0","doc":"","ref":"ExMCP.Protocol.html#t:result/0"},{"type":"module","title":"ExMCP.Types","doc":"Type definitions for the Model Context Protocol.\n\nThis module defines the core types used throughout ExMCP,\nmatching the MCP specification.","ref":"ExMCP.Types.html"},{"type":"type","title":"ExMCP.Types.capabilities/0","doc":"","ref":"ExMCP.Types.html#t:capabilities/0"},{"type":"type","title":"ExMCP.Types.client_info/0","doc":"","ref":"ExMCP.Types.html#t:client_info/0"},{"type":"type","title":"ExMCP.Types.completion_argument/0","doc":"","ref":"ExMCP.Types.html#t:completion_argument/0"},{"type":"type","title":"ExMCP.Types.content_part/0","doc":"","ref":"ExMCP.Types.html#t:content_part/0"},{"type":"type","title":"ExMCP.Types.error_code/0","doc":"","ref":"ExMCP.Types.html#t:error_code/0"},{"type":"type","title":"ExMCP.Types.image_content/0","doc":"","ref":"ExMCP.Types.html#t:image_content/0"},{"type":"type","title":"ExMCP.Types.initialize_result/0","doc":"","ref":"ExMCP.Types.html#t:initialize_result/0"},{"type":"type","title":"ExMCP.Types.json_schema/0","doc":"","ref":"ExMCP.Types.html#t:json_schema/0"},{"type":"type","title":"ExMCP.Types.log_level/0","doc":"","ref":"ExMCP.Types.html#t:log_level/0"},{"type":"type","title":"ExMCP.Types.prompt/0","doc":"","ref":"ExMCP.Types.html#t:prompt/0"},{"type":"type","title":"ExMCP.Types.prompt_argument/0","doc":"","ref":"ExMCP.Types.html#t:prompt_argument/0"},{"type":"type","title":"ExMCP.Types.prompt_content/0","doc":"","ref":"ExMCP.Types.html#t:prompt_content/0"},{"type":"type","title":"ExMCP.Types.prompt_message/0","doc":"","ref":"ExMCP.Types.html#t:prompt_message/0"},{"type":"type","title":"ExMCP.Types.resource/0","doc":"","ref":"ExMCP.Types.html#t:resource/0"},{"type":"type","title":"ExMCP.Types.resource_content/0","doc":"","ref":"ExMCP.Types.html#t:resource_content/0"},{"type":"type","title":"ExMCP.Types.resource_ref/0","doc":"","ref":"ExMCP.Types.html#t:resource_ref/0"},{"type":"type","title":"ExMCP.Types.server_info/0","doc":"","ref":"ExMCP.Types.html#t:server_info/0"},{"type":"type","title":"ExMCP.Types.text_content/0","doc":"","ref":"ExMCP.Types.html#t:text_content/0"},{"type":"type","title":"ExMCP.Types.tool/0","doc":"","ref":"ExMCP.Types.html#t:tool/0"},{"type":"type","title":"ExMCP.Types.tool_result/0","doc":"","ref":"ExMCP.Types.html#t:tool_result/0"},{"type":"type","title":"ExMCP.Types.transport/0","doc":"","ref":"ExMCP.Types.html#t:transport/0"},{"type":"module","title":"ExMCP.Client","doc":"MCP client for connecting to Model Context Protocol servers.\n\nThe client handles:\n- Connection management with automatic reconnection\n- Request/response correlation\n- Protocol message encoding/decoding\n- Concurrent request handling","ref":"ExMCP.Client.html"},{"type":"module","title":"Example - ExMCP.Client","doc":"# Connect to a filesystem server\n    {:ok, client} = ExMCP.Client.start_link(\n      transport: :stdio,\n      command: [\"npx\", \"-y\", \"@modelcontextprotocol/server-filesystem\", \"/tmp\"],\n      name: :fs_client\n    )\n    \n    # List available tools\n    {:ok, tools} = ExMCP.Client.list_tools(client)\n    \n    # Call a tool\n    {:ok, result} = ExMCP.Client.call_tool(client, \"read_file\", %{\n      \"path\" => \"/tmp/example.txt\"\n    })","ref":"ExMCP.Client.html#module-example"},{"type":"function","title":"ExMCP.Client.call_tool/4","doc":"Calls a tool with the given arguments.","ref":"ExMCP.Client.html#call_tool/4"},{"type":"function","title":"ExMCP.Client.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExMCP.Client.html#child_spec/1"},{"type":"function","title":"ExMCP.Client.get_prompt/4","doc":"Gets a prompt with the given arguments.","ref":"ExMCP.Client.html#get_prompt/4"},{"type":"function","title":"ExMCP.Client.list_prompts/2","doc":"Lists available prompts from the server.","ref":"ExMCP.Client.html#list_prompts/2"},{"type":"function","title":"ExMCP.Client.list_resources/2","doc":"Lists available resources from the server.","ref":"ExMCP.Client.html#list_resources/2"},{"type":"function","title":"ExMCP.Client.list_tools/2","doc":"Lists available tools from the server.","ref":"ExMCP.Client.html#list_tools/2"},{"type":"function","title":"ExMCP.Client.read_resource/3","doc":"Reads a resource by URI.","ref":"ExMCP.Client.html#read_resource/3"},{"type":"function","title":"ExMCP.Client.server_capabilities/1","doc":"Gets server capabilities.","ref":"ExMCP.Client.html#server_capabilities/1"},{"type":"function","title":"ExMCP.Client.server_info/1","doc":"Gets server information.","ref":"ExMCP.Client.html#server_info/1"},{"type":"function","title":"ExMCP.Client.start_link/1","doc":"Starts an MCP client.","ref":"ExMCP.Client.html#start_link/1"},{"type":"function","title":"Options - ExMCP.Client.start_link/1","doc":"- `:transport` - Transport type (:stdio, :sse, or module)\n- `:name` - GenServer name (optional)\n- `:client_info` - Client information map with :name and :version\n\nTransport-specific options are passed through.","ref":"ExMCP.Client.html#start_link/1-options"},{"type":"module","title":"ExMCP.Server","doc":"MCP server implementation.\n\nThis module handles the protocol layer for MCP servers, delegating\nthe actual functionality to a handler module that implements the\n`ExMCP.Server.Handler` behaviour.","ref":"ExMCP.Server.html"},{"type":"module","title":"Example - ExMCP.Server","doc":"defmodule MyHandler do\n      use ExMCP.Server.Handler\n      \n      @impl true\n      def handle_initialize(_params, state) do\n        {:ok, %{\n          server_info: %{name: \"my-server\", version: \"1.0.0\"},\n          capabilities: %{tools: %{}}\n        }, state}\n      end\n      \n      # ... implement other callbacks ...\n    end\n    \n    # Start server on stdio\n    {:ok, server} = ExMCP.Server.start_link(\n      handler: MyHandler,\n      transport: :stdio\n    )","ref":"ExMCP.Server.html#module-example"},{"type":"function","title":"ExMCP.Server.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExMCP.Server.html#child_spec/1"},{"type":"function","title":"ExMCP.Server.start_link/1","doc":"Starts an MCP server.","ref":"ExMCP.Server.html#start_link/1"},{"type":"function","title":"Options - ExMCP.Server.start_link/1","doc":"- `:handler` - Module implementing `ExMCP.Server.Handler` behaviour (required)\n- `:transport` - Transport type (:stdio, :sse, or module)\n- `:handler_args` - Arguments passed to handler's init/1 callback\n- `:name` - GenServer name (optional)\n\nTransport-specific options are passed through.","ref":"ExMCP.Server.html#start_link/1-options"},{"type":"behaviour","title":"ExMCP.Server.Handler","doc":"Behaviour for implementing MCP server handlers.\n\nTo create an MCP server, implement this behaviour in your module:\n\n    defmodule MyServer do\n      use ExMCP.Server.Handler\n      \n      @impl true\n      def handle_initialize(_params, state) do\n        {:ok, %{\n          server_info: %{\n            name: \"my-server\",\n            version: \"1.0.0\"\n          },\n          capabilities: %{\n            tools: %{},\n            resources: %{list: true, read: true}\n          }\n        }, state}\n      end\n      \n      @impl true\n      def handle_list_tools(state) do\n        tools = [\n          %{\n            name: \"hello\",\n            description: \"Says hello\",\n            input_schema: %{\n              type: \"object\",\n              properties: %{\n                \"name\" => %{type: \"string\"}\n              },\n              required: [\"name\"]\n            }\n          }\n        ]\n        {:ok, tools, state}\n      end\n      \n      @impl true\n      def handle_call_tool(\"hello\", %{\"name\" => name}, state) do\n        result = [%{type: \"text\", text: \"Hello, #{name}!\"}]\n        {:ok, result, state}\n      end\n      \n      # ... implement other handlers ...\n    end\n\nThe `use` macro provides default implementations for all callbacks\nthat return appropriate \"not implemented\" responses.","ref":"ExMCP.Server.Handler.html"},{"type":"callback","title":"ExMCP.Server.Handler.handle_call_tool/3","doc":"Handles a tool call.","ref":"ExMCP.Server.Handler.html#c:handle_call_tool/3"},{"type":"callback","title":"ExMCP.Server.Handler.handle_complete/3","doc":"Handles a completion request.","ref":"ExMCP.Server.Handler.html#c:handle_complete/3"},{"type":"callback","title":"ExMCP.Server.Handler.handle_get_prompt/3","doc":"Handles getting a prompt.","ref":"ExMCP.Server.Handler.html#c:handle_get_prompt/3"},{"type":"callback","title":"ExMCP.Server.Handler.handle_initialize/2","doc":"Handles the initialize request from a client.\n\nShould return server information and capabilities.","ref":"ExMCP.Server.Handler.html#c:handle_initialize/2"},{"type":"callback","title":"ExMCP.Server.Handler.handle_list_prompts/1","doc":"Handles listing available prompts.","ref":"ExMCP.Server.Handler.html#c:handle_list_prompts/1"},{"type":"callback","title":"ExMCP.Server.Handler.handle_list_resources/1","doc":"Handles listing available resources.","ref":"ExMCP.Server.Handler.html#c:handle_list_resources/1"},{"type":"callback","title":"ExMCP.Server.Handler.handle_list_tools/1","doc":"Handles listing available tools.","ref":"ExMCP.Server.Handler.html#c:handle_list_tools/1"},{"type":"callback","title":"ExMCP.Server.Handler.handle_read_resource/2","doc":"Handles reading a resource.","ref":"ExMCP.Server.Handler.html#c:handle_read_resource/2"},{"type":"callback","title":"ExMCP.Server.Handler.init/1","doc":"Called when the handler process is started.","ref":"ExMCP.Server.Handler.html#c:init/1"},{"type":"type","title":"ExMCP.Server.Handler.initialize_result/0","doc":"","ref":"ExMCP.Server.Handler.html#t:initialize_result/0"},{"type":"type","title":"ExMCP.Server.Handler.prompt/0","doc":"","ref":"ExMCP.Server.Handler.html#t:prompt/0"},{"type":"type","title":"ExMCP.Server.Handler.resource/0","doc":"","ref":"ExMCP.Server.Handler.html#t:resource/0"},{"type":"type","title":"ExMCP.Server.Handler.state/0","doc":"","ref":"ExMCP.Server.Handler.html#t:state/0"},{"type":"callback","title":"ExMCP.Server.Handler.terminate/2","doc":"Called when the handler process is terminating.","ref":"ExMCP.Server.Handler.html#c:terminate/2"},{"type":"type","title":"ExMCP.Server.Handler.tool/0","doc":"","ref":"ExMCP.Server.Handler.html#t:tool/0"},{"type":"module","title":"ExMCP.Discovery","doc":"MCP server discovery functionality.\n\nProvides mechanisms to discover available MCP servers through:\n- Environment variables\n- Configuration files\n- Well-known locations\n- Service registration","ref":"ExMCP.Discovery.html"},{"type":"function","title":"ExMCP.Discovery.discover_from_config/1","doc":"Discovers servers from configuration files.\n\nLooks for mcp.json or .mcp/config.json in:\n- Current directory\n- Home directory\n- XDG config directory","ref":"ExMCP.Discovery.html#discover_from_config/1"},{"type":"function","title":"ExMCP.Discovery.discover_from_env/1","doc":"Discovers servers from environment variables.\n\nLooks for MCP_SERVERS environment variable containing\na JSON array of server configurations.","ref":"ExMCP.Discovery.html#discover_from_env/1"},{"type":"function","title":"ExMCP.Discovery.discover_from_well_known/1","doc":"Discovers servers from well-known locations.\n\nChecks standard locations where MCP servers might be installed:\n- System paths\n- User local directories\n- Application bundles","ref":"ExMCP.Discovery.html#discover_from_well_known/1"},{"type":"function","title":"ExMCP.Discovery.discover_servers/0","doc":"Discovers available MCP servers from various sources.\n\nReturns a list of server configurations that can be used\nto establish connections.","ref":"ExMCP.Discovery.html#discover_servers/0"},{"type":"function","title":"ExMCP.Discovery.register_server/1","doc":"Registers a server for discovery.\n\nThis allows programmatic registration of servers that\nmay not be discoverable through other means.","ref":"ExMCP.Discovery.html#register_server/1"},{"type":"module","title":"ExMCP.ServerManager","doc":"Manages multiple MCP server connections.\n\nThe ServerManager provides a centralized way to:\n- Start and stop multiple MCP servers\n- Route requests to appropriate servers\n- Monitor server health\n- Handle server lifecycle","ref":"ExMCP.ServerManager.html"},{"type":"function","title":"ExMCP.ServerManager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ExMCP.ServerManager.html#child_spec/1"},{"type":"function","title":"ExMCP.ServerManager.discover_and_start/1","doc":"Discovers and starts servers based on configuration.","ref":"ExMCP.ServerManager.html#discover_and_start/1"},{"type":"function","title":"ExMCP.ServerManager.get_server/2","doc":"Gets information about a specific server.","ref":"ExMCP.ServerManager.html#get_server/2"},{"type":"function","title":"ExMCP.ServerManager.list_servers/1","doc":"Lists all managed servers.","ref":"ExMCP.ServerManager.html#list_servers/1"},{"type":"function","title":"ExMCP.ServerManager.route_request/3","doc":"Routes a request to the appropriate server.","ref":"ExMCP.ServerManager.html#route_request/3"},{"type":"type","title":"ExMCP.ServerManager.server_spec/0","doc":"","ref":"ExMCP.ServerManager.html#t:server_spec/0"},{"type":"function","title":"ExMCP.ServerManager.start_link/1","doc":"Starts the server manager.","ref":"ExMCP.ServerManager.html#start_link/1"},{"type":"function","title":"ExMCP.ServerManager.start_server/2","doc":"Starts a new MCP server.","ref":"ExMCP.ServerManager.html#start_server/2"},{"type":"function","title":"ExMCP.ServerManager.stop_server/2","doc":"Stops a running MCP server.","ref":"ExMCP.ServerManager.html#stop_server/2"},{"type":"behaviour","title":"ExMCP.Transport","doc":"Behaviour for MCP transport implementations.\n\nA transport is responsible for sending and receiving MCP protocol\nmessages over a specific communication channel (stdio, SSE, WebSocket, etc).","ref":"ExMCP.Transport.html"},{"type":"behaviour","title":"Implementing a Transport - ExMCP.Transport","doc":"To implement a custom transport, create a module that implements\nall the callbacks defined in this behaviour:\n\n    defmodule MyTransport do\n      @behaviour ExMCP.Transport\n      \n      @impl true\n      def connect(opts) do\n        # Establish connection\n        {:ok, state}\n      end\n      \n      @impl true\n      def send_message(message, state) do\n        # Send the message\n        {:ok, state}\n      end\n      \n      @impl true\n      def receive_message(state) do\n        # Receive a message (blocking)\n        {:ok, message, state}\n      end\n      \n      @impl true\n      def close(state) do\n        # Clean up\n        :ok\n      end\n    end","ref":"ExMCP.Transport.html#module-implementing-a-transport"},{"type":"callback","title":"ExMCP.Transport.close/1","doc":"Closes the transport connection.\n\nShould clean up any resources and return `:ok`.","ref":"ExMCP.Transport.html#c:close/1"},{"type":"callback","title":"ExMCP.Transport.connect/1","doc":"Establishes a connection for the transport.\n\nOptions are transport-specific. Should return `{:ok, state}`\nwhere state contains any necessary connection information.","ref":"ExMCP.Transport.html#c:connect/1"},{"type":"callback","title":"ExMCP.Transport.connected?/1","doc":"Optional callback to check if the transport is still connected.\n\nDefault implementation always returns true.","ref":"ExMCP.Transport.html#c:connected?/1"},{"type":"function","title":"ExMCP.Transport.get_transport/1","doc":"Helper to get the appropriate transport module for an atom identifier.","ref":"ExMCP.Transport.html#get_transport/1"},{"type":"type","title":"ExMCP.Transport.message/0","doc":"","ref":"ExMCP.Transport.html#t:message/0"},{"type":"type","title":"ExMCP.Transport.opts/0","doc":"","ref":"ExMCP.Transport.html#t:opts/0"},{"type":"callback","title":"ExMCP.Transport.receive_message/1","doc":"Receives a message from the transport.\n\nThis should block until a message is available. Returns\n`{:ok, message, new_state}` where message is a JSON string.","ref":"ExMCP.Transport.html#c:receive_message/1"},{"type":"callback","title":"ExMCP.Transport.send_message/2","doc":"Sends a message through the transport.\n\nThe message will be a JSON-encoded string. Should return\n`{:ok, new_state}` on success.","ref":"ExMCP.Transport.html#c:send_message/2"},{"type":"type","title":"ExMCP.Transport.state/0","doc":"","ref":"ExMCP.Transport.html#t:state/0"},{"type":"extras","title":"ExMCP","doc":"# ExMCP\n\nModel Context Protocol client/server library for Elixir.","ref":"readme.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [0.1.0] - 2025-01-27","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release of ExMCP\n- Complete Model Context Protocol implementation\n- Protocol encoder/decoder for JSON-RPC messages\n- Client implementation with automatic reconnection\n- Server implementation with handler behaviour\n- stdio transport for process communication\n- SSE (Server-Sent Events) transport for HTTP streaming\n- Tool discovery and execution\n- Resource listing and reading\n- Prompt management\n- Server manager for multiple connections\n- Server discovery (npm packages, local directories)\n- Server configuration persistence\n- Request/response correlation\n- Concurrent request handling\n- Error handling and validation\n- Comprehensive documentation and examples","ref":"changelog.html#added"},{"type":"extras","title":"Features - Changelog","doc":"- Full MCP specification compliance\n- Multiple transport layer support\n- Both client and server implementations\n- Extensible architecture\n- Supervision tree integration\n- Type specifications throughout","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}